@@ -88,10 +88,17 @@ def get_settings(key):
     try:
         return get_settings_at_path(key)
     except JanrainConfigError:
+        if '.' in key:
+            raise
         try:
             return get_settings_at_path("clients." + key)
         except JanrainConfigError:
-            return get_settings_at_path("clusters." + key)
+            try:
+                return get_settings_at_path("clusters." + key)
+            except JanrainConfigError:
+                raise JanrainConfigError("Could not find '{0}', 'clients.{0}',"\
+                    " or 'clusters.{0}' in '{1}'".format(key,
+                                                         get_config_file()))
 
 def get_clusters():
     """
